@@ -158,6 +158,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_cloudwatch
@@ -186,9 +188,9 @@ class KinesisStreamsToLambda(
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_event_source_props: typing.Any = None,
-        kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
-        sqs_dlq_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        sqs_dlq_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -206,6 +208,10 @@ class KinesisStreamsToLambda(
         :since: 0.8.0
         :summary: Constructs a new instance of the KinesisStreamsToLambda class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(KinesisStreamsToLambda.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = KinesisStreamsToLambdaProps(
             create_cloud_watch_alarms=create_cloud_watch_alarms,
             deploy_sqs_dlq_queue=deploy_sqs_dlq_queue,
@@ -260,9 +266,9 @@ class KinesisStreamsToLambdaProps:
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_event_source_props: typing.Any = None,
-        kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
-        sqs_dlq_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        sqs_dlq_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''The properties for the KinesisStreamsToLambda class.
 
@@ -281,6 +287,16 @@ class KinesisStreamsToLambdaProps:
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(sqs_dlq_queue_props, dict):
             sqs_dlq_queue_props = aws_cdk.aws_sqs.QueueProps(**sqs_dlq_queue_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(KinesisStreamsToLambdaProps.__init__)
+            check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
+            check_type(argname="argument deploy_sqs_dlq_queue", value=deploy_sqs_dlq_queue, expected_type=type_hints["deploy_sqs_dlq_queue"])
+            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
+            check_type(argname="argument existing_stream_obj", value=existing_stream_obj, expected_type=type_hints["existing_stream_obj"])
+            check_type(argname="argument kinesis_event_source_props", value=kinesis_event_source_props, expected_type=type_hints["kinesis_event_source_props"])
+            check_type(argname="argument kinesis_stream_props", value=kinesis_stream_props, expected_type=type_hints["kinesis_stream_props"])
+            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
+            check_type(argname="argument sqs_dlq_queue_props", value=sqs_dlq_queue_props, expected_type=type_hints["sqs_dlq_queue_props"])
         self._values: typing.Dict[str, typing.Any] = {}
         if create_cloud_watch_alarms is not None:
             self._values["create_cloud_watch_alarms"] = create_cloud_watch_alarms
